==> V00.73.zip: tweet_live-V00.73/web/embed_form.php <==
<?php

/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
$rep = $_REQUEST['rep'];
include_once dirname(__FILE__).'/'.$rep.'/config.php';
include_once 'common.php';

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>embed Configuration</title>
	
	<link rel="stylesheet" href="<?php echo(URL_ROOT); ?>res/css/custom.css" type="text/css" media="screen, projection">
	
	<!-- FONT -->
	<link href='<?php echo(registry_url('PT-Sans_Narrow','font'))?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('PT-Sans','font'))?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('Geo','font'))?>' rel='stylesheet' type='text/css'>

	<style type="text/css"> 
		body{
			padding:0px;
			margin:0px;
			background-image:none;
			width:300px;
			padding:5px;
		}
		textarea {
			margin-left:3px;
			height: 150px;
			width: 330px;
			padding:5px;
			background-image:none;
			border:solid 1px #ccc;
		}
	</style>
	<script type="text/javascript">
	
	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-23581291-1']);
	  _gaq.push(['_trackPageview']);
	
	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();
	
	</script>
  </head>
  
  <h1 class="tweetWriterTitle" style="width:300px;" > <?php print $translate->_("EmbedTitle"); ?></h1>
  
  <p style="font-size:12px;width:300px;"><?php print $translate->_("EmbedText"); ?> </p>
  <textarea cols="10" rows="10"><iframe src="<?php echo(URL_ROOT.$rep); ?>/player_embed.php<?php echo(array_key_exists("metadata",$_GET)?"?metadata=".$_GET["metadata"]:""); ?>" width="<?php echo($config['player_width']); ?>" height="<?php echo($config['player_height']); ?>" frameborder="0"></iframe><p><a href="<?php echo(URL_ROOT.$rep); ?>/polemicaltimeline.php<?php echo(array_key_exists("metadata",$_GET)?"#metadata=".$_GET["metadata"]:""); ?>">Source</a> on <a href="<?php echo(URL_ROOT); ?>">PolemicTweet</a>.</p>
  </textarea>

  </body>
</html>

==> V08.001.zip: tweet_live-V08.001/web/embed_form.php <==
<?php

/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
$rep = $_REQUEST['rep'];
include_once dirname(__FILE__).'/'.$rep.'/config.php';
include_once 'common.php';

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>embed Configuration</title>
	
	<link rel="stylesheet" href="<?php echo(registry_url('custom', 'css')); ?>" type="text/css" media="screen, projection">
	
	<!-- FONT -->
	<link href='<?php echo(registry_url('PT-Sans_Narrow','font'))?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('PT-Sans','font'))?>' rel='stylesheet' type='text/css'>

	<style type="text/css"> 
		body{
			padding:0px;
			margin:0px;
			background-image:none;
			width:300px;
			padding:5px;
		}
		textarea {
			margin-left:3px;
			height: 150px;
			width: 330px;
			padding:5px;
			background-image:none;
			border:solid 1px #ccc;
			font-size: 12px;
		}
	</style>
  </head>
  
  <h1 class="tweetWriterTitle" style="width:300px;" > <?php print $translate->_("EmbedTitle"); ?></h1>
  
  <p style="font-size:12px;width:300px;"><?php print $translate->_("EmbedText"); ?> </p>
  <textarea cols="10" rows="10"><div id="metadataplayer_embed"></div><script type="text/javascript" src="<?php echo(URL_ROOT.$rep); ?>/embedscript.php<?php echo(array_key_exists("metadata",$_GET)?"?metadata=".$_GET["metadata"]:""); ?>"></script></textarea>

  </body>
</html>
